==> ldapsaisie_3.0.1-1.tar.gz: ldapsaisie_clean3/src/lang/fr_FR.UTF8/lang.php <==
<?php

$GLOBALS['LSlang'] = array (

# LSobjects.LSpeople.attrs.lsGodfatherDn.label
# LSobjects.LSgroup.attrs.lsGodfatherDn.label
# LSobjects.LScompany.attrs.lsGodfatherDn.label
"Accountable(s)" =>
  "Responsable(s)",

# ldap_servers.0.LSprofiles.admin.label
"Administrator" =>
  "Administrateur",

# LSobjects.LSpeople.attrs.loginShell.help_info
"Allow user to connect a POSIX system." =>
  "Autorisie l'utilisateur à se connecter aux systèmes POSIX.",

# LSobjects.LSpeople.LSrelation.groups.label
# LSobjects.LSsysaccount.LSrelation.groups.label
"Belongs to groups ..." =>
  "Appartient aux groupes ...",

# LSobjects.LSpeople.LSform.layout.Civilite.label
# LSobjects.LSpeople.attrs.personalTitle.label
"Civility" =>
  "Civilité",

# LSobjects.LSpeople.attrs.loginShell.label
"Command shell" =>
  "Interpréteur de commande",

# LSobjects.LScompany.label
"Companies" =>
  "Sociétés",

# ldap_servers.1.subDnLabel
"Company" =>
  "Société",

# LSobjects.LSpeople.attrs.description.label
# LSobjects.LSgroup.attrs.description.label
# LSobjects.LSsysaccount.attrs.description.label
# LSobjects.LScompany.attrs.description.label
"Description" =>
  "Description",

# LSobjects.LSpeople.attrs.userPassword.html_options.confirmChangeQuestion
"Do you confirm change of this user's password?" =>
  "Confirmez-vous le changement du mot de passe de cet utilisateur ?",

# LSobjects.LSpeople.LSrelation.groups.emptyText
# LSobjects.LSsysaccount.LSrelation.groups.emptyText
"Doesn't belong to any group." =>
  "N'appartient à aucun groupe.",

# LSobjects.LSpeople.LSrelation.godfather.emptyText
"Doesn't sponsor any user." =>
  "Ne parraine aucun utilisateur.",

# LSobjects.LSpeople.attrs.mail.label
"E-mail address" =>
  "Adresse e-mail",

# LSobjects.LSpeople.LSsearch.customActions.exportSearchResultAsCSV.label
"Export result as CSV" =>
  "Exporter le résultat au format CSV",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.filesize.msg
"File size is not valid." =>
  "La taille du fichier est invalide.",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.imagefile.msg
"File type is not valid." =>
  "Le type de fichier est invalide.",

# LSobjects.LSpeople.attrs.givenName.label
"First Name" =>
  "Prénom",

# templates/default/import.tpl:13
"Format" =>
  "Format",

# LSobjects.LSpeople.attrs.cn.label
"Full Name" =>
  "Nom complet",

# LSobjects.LSpeople.attrs.mail.check_data.email.msg
"Given email address is invalid." =>
  "L'adresse mail saisie est invalide.",

# ldap_servers.0.LSprofiles.godfather.label
"Godfather" =>
  "Parrain",

# LSobjects.LSpeople.LSrelation.godfather.label
"Godfather of ..." =>
  "Parrain de ...",

# LSobjects.LSgroup.label
"Groups" =>
  "Groupes",

# LSobjects.LSpeople.attrs.homeDirectory.label
"Home Directory" =>
  "Dossier personnel",

# LSobjects.LSpeople.attrs.uid.check_data.regex.msg
# LSobjects.LSsysaccount.attrs.uid.check_data.regex.msg
"Identifier must contain alphanumeric values, dots (.) and dashes (-) only." =>
  "L'identifiant doit contenir uniquement des valeurs alpha-numériques, avec eventuellement des points (.) et des tirets (-).",

# LSobjects.LSpeople.attrs.gidNumber.html_options.possible_values.1.label
"LDAP Groups" =>
  "Groupes LDAP",

# ldap_servers.0.name
"LSexample" =>
  "LSexemple",

# ldap_servers.1.name
"LSexample - multi-company" =>
  "LSexemple - multi-société",

# ldap_servers.0.recoverPassword.recoveryHashMail.subject
# ldap_servers.1.recoverPassword.recoveryHashMail.subject
"LSexample : Recovering your password." =>
  "LSexemple : Récupération de votre mot de passe.",

# ldap_servers.0.recoverPassword.newPasswordMail.subject
# ldap_servers.1.recoverPassword.newPasswordMail.subject
# LSobjects.LSpeople.attrs.userPassword.html_options.mail.subject
"LSexample : Your new credentials." =>
  "LSexemple : Votre nouveau mot de passe.",

# LSobjects.LSpeople.attrs.sn.label
"Last Name" =>
  "Nom",

# LSobjects.LSpeople.LSsearch.extraDisplayedColumns.mail.label
"Mail" =>
  "Mail",

# LSobjects.LSpeople.attrs.gidNumber.label
"Main group" =>
  "Groupe principal",

# LSobjects.LSgroup.attrs.uniqueMember.label
"Members" =>
  "Membres",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.M.
"Mr" =>
  "M.",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.Mme
"Mrs" =>
  "Mme",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.Mlle
"Ms" =>
  "Mlle",

# LSobjects.LSgroup.attrs.cn.label
# LSobjects.LScompany.attrs.ou.label
"Name" =>
  "Nom",

# LSobjects.LSgroup.attrs.cn.check_data.alphanumeric.msg
"Name must contain alphanumeric values only." =>
  "Le nom doit contenir uniquement des valeurs alpha-numériques.",

# templates/default/viewSearch.tpl:134
"Nb / page :" =>
  "Nb / page :",

# LSobjects.LSpeople.attrs.uidNumber.label
"Numeric identifier" =>
  "Identifiant numérique",

# LSobjects.LSgroup.attrs.lsGodfatherDn.validation.0.msg
# LSobjects.LScompany.attrs.lsGodfatherDn.validation.0.msg
"One or several of these users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

# LSobjects.LSpeople.attrs.lsGodfatherDn.validation.0.msg
"One or several users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

# LSobjects.LSpeople.attrs.lsRecoveryHash.label
"Password recovery hash" =>
  "Hash de récupération de mot de passe",

# LSobjects.LSpeople.attrs.jpegPhoto.label
"Picture" =>
  "Image",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.imagesize.msg
"Picture size is not valid." =>
  "La taille de l'image est invalide.",

# LSobjects.LSpeople.LSform.layout.Posix.label
"Posix" =>
  "Posix",

# LSobjects.LSpeople.LSform.layout.Samba.label
"Samba" =>
  "Samba",

# LSobjects.LSpeople.attrs.sambaSID.label
"Samba Identifier" =>
  "Identifiant Samba",

# LSobjects.LSpeople.attrs.sambaLMPassword.label
"Samba Password (LM)" =>
  "Mot de passe Samba (LM)",

# LSobjects.LSpeople.attrs.sambaNTPassword.label
"Samba Password (NT)" =>
  "Mot de passe Samba (NT)",

# LSobjects.LSpeople.LSform.dataEntryForm.simple.label
"Simple" =>
  "Simple",

# LSobjects.LSsysaccount.label
"System accounts" =>
  "Comptes systèmes",

# LSobjects.LSpeople.attrs.givenName.check_data.alphanumeric.msg
"The first name must contain alphanumeric values only." =>
  "Le prénom doit contenir uniquement des caractères alpha-numérique.",

# LSobjects.LSpeople.attrs.uidNumber.check_data.numeric.msg
"The numeric identifier must be an integer." =>
  "L'identifiant numérique doit forcement être un entier.",

# LSobjects.LSpeople.attrs.gidNumber.validation.0.msg
"This group doesn't exist." =>
  "Ce groupe n'existe pas.",

# LSobjects.LSpeople.attrs.uid.validation.0.msg
# LSobjects.LSsysaccount.attrs.uid.validation.0.msg
"This identifier is already used." =>
  "Cet identifiant est déjà utilisé.",

# LSobjects.LSsysaccount.attrs.userPassword.check_data.password.msg
"This password must contain at least 12 characters." =>
  "Ce mot de passe doit contenir au moins 12 caractères.",

# LSobjects.LSpeople.attrs.uidNumber.validation.0.msg
"This uid is already used." =>
  "Cet uid est déjà utilisé.",

# ldap_servers.0.recoverPassword.recoveryHashMail.msg
# ldap_servers.1.recoverPassword.recoveryHashMail.msg
"To proceed password recovery procedure, please follow that link:
%{url}" =>
  "Pour poursuivre la procédure de récupération de mot de passe, merci de suivre ce lien :
%{url}",

# LSobjects.LSpeople.label
"Users" =>
  "Utilisateurs",

# LSobjects.LSpeople.LSsearch.predefinedFilters.(jpegPhoto=*)
"With photo" =>
  "Avec photo",

# LSobjects.LSpeople.LSsearch.predefinedFilters.(!(jpegPhoto=*))
"Without photo" =>
  "Sans photo",

# ldap_servers.0.recoverPassword.newPasswordMail.msg
# ldap_servers.1.recoverPassword.newPasswordMail.msg
"Your new password : %{mdp}" =>
  "Votre nouveau mot de passe : %{mdp}",

# LSobjects.LSpeople.attrs.userPassword.html_options.mail.msg
"Your password has been changed.
Login : %{uid}
New password : %{password}" =>
  "Votre mot de passe a été changé.
Identifiant : %{uid}
Nouveau mot de passe : %{password}",

# LSobjects.LSpeople.attrs.userPassword.check_data.password.msg
"Your password must contain from 8 to 10 characters and contains at least one caracter that match with 3 of this types :<ul><li>Uppercase unaccent character</li><li>Lowercase unaccent character</li><li>Digit</li><li>Anything that is not a letter or a digit</li></ul>" =>
  "Votre mot de passe doit contenir entre 8 et 10 caractères et comprendre au moins un caractère correspondant à au moins trois des types suivant :<ul><li>Une lettre majuscule sans accent</li><li>Une lettre minuscule sans accent</li><li>Un chiffre</li><li>Un caractère autre qu'une lettre ou un chiffre</li></ul>",

);

==> ldapsaisie_3.0.2-1.tar.gz: ldapsaisie_clean3/src/lang/fr_FR.UTF8/lang.php <==
<?php

$GLOBALS['LSlang'] = array (

# LSobjects.LSpeople.attrs.lsGodfatherDn.label
# LSobjects.LSgroup.attrs.lsGodfatherDn.label
# LSobjects.LScompany.attrs.lsGodfatherDn.label
"Accountable(s)" =>
  "Responsable(s)",

# ldap_servers.0.LSprofiles.admin.label
"Administrator" =>
  "Administrateur",

# LSobjects.LSpeople.attrs.loginShell.help_info
"Allow user to connect a POSIX system." =>
  "Autorisie l'utilisateur à se connecter aux systèmes POSIX.",

# LSobjects.LSpeople.attrs.shadowExpire.html_options.special_values.0
"Always (disable account)" =>
  "Toujours (compte désactivé)",

# LSobjects.LSpeople.attrs.sambaPwdMustChange.html_options.special_values.0
"At first login" =>
  "À la première connexion",

# LSobjects.LSpeople.LSrelation.groups.label
# LSobjects.LSsysaccount.LSrelation.groups.label
"Belongs to groups ..." =>
  "Appartient aux groupes ...",

# LSobjects.LSpeople.LSform.layout.Civilite.label
# LSobjects.LSpeople.attrs.personalTitle.label
"Civility" =>
  "Civilité",

# LSobjects.LSpeople.attrs.loginShell.label
"Command shell" =>
  "Interpréteur de commande",

# LSobjects.LScompany.label
"Companies" =>
  "Sociétés",

# ldap_servers.1.subDnLabel
"Company" =>
  "Société",

# LSobjects.LSpeople.attrs.sambaKickoffTime.no_value_label
# LSobjects.LSpeople.attrs.sambaPwdMustChange.no_value_label
"Default (never)" =>
  "Par défaut (jamais)",

# LSobjects.LSpeople.attrs.sambaPwdCanChange.no_value_label
"Default (whenever)" =>
  "Par défaut (n'importe quand)",

# LSobjects.LSpeople.attrs.description.label
# LSobjects.LSgroup.attrs.description.label
# LSobjects.LSsysaccount.attrs.description.label
# LSobjects.LScompany.attrs.description.label
"Description" =>
  "Description",

# LSobjects.LSpeople.attrs.userPassword.html_options.confirmChangeQuestion
"Do you confirm change of this user's password?" =>
  "Confirmez-vous le changement du mot de passe de cet utilisateur ?",

# LSobjects.LSpeople.LSrelation.groups.emptyText
# LSobjects.LSsysaccount.LSrelation.groups.emptyText
"Doesn't belong to any group." =>
  "N'appartient à aucun groupe.",

# LSobjects.LSpeople.LSrelation.godfather.emptyText
"Doesn't sponsor any user." =>
  "Ne parraine aucun utilisateur.",

# LSobjects.LSpeople.attrs.mail.label
"E-mail address" =>
  "Adresse e-mail",

# LSobjects.LSpeople.LSsearch.customActions.exportSearchResultAsCSV.label
"Export result as CSV" =>
  "Exporter le résultat au format CSV",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.filesize.msg
"File size is not valid." =>
  "La taille du fichier est invalide.",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.imagefile.msg
"File type is not valid." =>
  "Le type de fichier est invalide.",

# LSobjects.LSpeople.attrs.givenName.label
"First Name" =>
  "Prénom",

# templates/default/import.tpl:13
"Format" =>
  "Format",

# LSobjects.LSpeople.attrs.cn.label
"Full Name" =>
  "Nom complet",

# LSobjects.LSpeople.attrs.gecos.label
"Gecos" =>
  "Gecos",

# LSobjects.LSpeople.attrs.mail.check_data.email.msg
"Given email address is invalid." =>
  "L'adresse mail saisie est invalide.",

# ldap_servers.0.LSprofiles.godfather.label
"Godfather" =>
  "Parrain",

# LSobjects.LSpeople.LSrelation.godfather.label
"Godfather of ..." =>
  "Parrain de ...",

# LSobjects.LSgroup.label
"Groups" =>
  "Groupes",

# LSobjects.LSpeople.attrs.homeDirectory.label
"Home Directory" =>
  "Dossier personnel",

# LSobjects.LSpeople.attrs.uid.check_data.regex.msg
# LSobjects.LSsysaccount.attrs.uid.check_data.regex.msg
"Identifier must contain alphanumeric values, dots (.) and dashes (-) only." =>
  "L'identifiant doit contenir uniquement des valeurs alpha-numériques, avec eventuellement des points (.) et des tirets (-).",

# LSobjects.LSpeople.attrs.sambaPwdCanChange.help_info
"If not set, the user will be free to change his password whenever he wants." =>
  "Si non défini, l'utilisateur pourra changer son mot de passe quand il le veut.",

# LSobjects.LSpeople.attrs.shadowInactive.label
"Inactivity allowed (in days)" =>
  "Durée d'inactivité autorisée (en jours)",

# LSobjects.LSpeople.attrs.gidNumber.html_options.possible_values.1.label
"LDAP Groups" =>
  "Groupes LDAP",

# ldap_servers.0.name
"LSexample" =>
  "LSexemple",

# ldap_servers.1.name
"LSexample - multi-company" =>
  "LSexemple - multi-société",

# ldap_servers.0.recoverPassword.recoveryHashMail.subject
# ldap_servers.1.recoverPassword.recoveryHashMail.subject
"LSexample : Recovering your password." =>
  "LSexemple : Récupération de votre mot de passe.",

# ldap_servers.0.recoverPassword.newPasswordMail.subject
# ldap_servers.1.recoverPassword.newPasswordMail.subject
# LSobjects.LSpeople.attrs.userPassword.html_options.mail.subject
"LSexample : Your new credentials." =>
  "LSexemple : Votre nouveau mot de passe.",

# LSobjects.LSpeople.attrs.sn.label
"Last Name" =>
  "Nom",

# LSobjects.LSpeople.LSsearch.extraDisplayedColumns.mail.label
"Mail" =>
  "Mail",

# LSobjects.LSpeople.attrs.gidNumber.label
"Main group" =>
  "Groupe principal",

# LSobjects.LSgroup.attrs.uniqueMember.label
"Members" =>
  "Membres",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.M.
"Mr" =>
  "M.",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.Mme
"Mrs" =>
  "Mme",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.Mlle
"Ms" =>
  "Mlle",

# LSobjects.LSgroup.attrs.cn.label
# LSobjects.LScompany.attrs.ou.label
"Name" =>
  "Nom",

# LSobjects.LSgroup.attrs.cn.check_data.alphanumeric.msg
"Name must contain alphanumeric values only." =>
  "Le nom doit contenir uniquement des valeurs alpha-numériques.",

# templates/default/viewSearch.tpl:113
"Nb / page :" =>
  "Nb / page :",

# LSobjects.LSpeople.attrs.shadowLastChange.no_value_label
# LSobjects.LSpeople.attrs.sambaLogonTime.no_value_label
# LSobjects.LSpeople.attrs.sambaLogoffTime.no_value_label
# LSobjects.LSpeople.attrs.sambaKickoffTime.html_options.special_values.2147483647
# LSobjects.LSpeople.attrs.sambaPwdLastSet.no_value_label
# LSobjects.LSpeople.attrs.sambaPwdMustChange.html_options.special_values.2147483647
# LSobjects.LSpeople.attrs.sambaPwdCanChange.html_options.special_values.2147483647
"Never" =>
  "Jamais",

# LSobjects.LSpeople.attrs.uidNumber.label
"Numeric identifier" =>
  "Identifiant numérique",

# LSobjects.LSgroup.attrs.lsGodfatherDn.validation.0.msg
# LSobjects.LScompany.attrs.lsGodfatherDn.validation.0.msg
"One or several of these users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

# LSobjects.LSpeople.attrs.lsGodfatherDn.validation.0.msg
"One or several users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

# LSobjects.LSpeople.attrs.shadowExpire.label
"Password expiration" =>
  "Expiration du mot de passe",

# LSobjects.LSpeople.attrs.shadowLastChange.label
"Password last change time" =>
  "Dernière modification du mot de passe",

# LSobjects.LSpeople.attrs.lsRecoveryHash.label
"Password recovery hash" =>
  "Hash de récupération de mot de passe",

# LSobjects.LSpeople.attrs.shadowMax.label
"Password validity (in days)" =>
  "Durée de validité du mot de passe (en jours)",

# LSobjects.LSpeople.attrs.jpegPhoto.label
"Picture" =>
  "Image",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.imagesize.msg
"Picture size is not valid." =>
  "La taille de l'image est invalide.",

# LSobjects.LSpeople.LSform.layout.Posix.label
"Posix" =>
  "Posix",

# LSobjects.LSpeople.LSform.layout.Samba.label
"Samba" =>
  "Samba",

# LSobjects.LSpeople.attrs.sambaSID.label
"Samba Identifier" =>
  "Identifiant Samba",

# LSobjects.LSpeople.attrs.sambaLMPassword.label
"Samba Password (LM)" =>
  "Mot de passe Samba (LM)",

# LSobjects.LSpeople.attrs.sambaNTPassword.label
"Samba Password (NT)" =>
  "Mot de passe Samba (NT)",

# LSobjects.LSpeople.attrs.sambaAcctFlags.label
"Samba account flags" =>
  "Drapeaux de compte Samba",

# LSobjects.LSpeople.attrs.sambaKickoffTime.label
"Samba expiration time" =>
  "Date d'expiration Samba",

# LSobjects.LSpeople.attrs.sambaLogoffTime.label
"Samba last logoff time" =>
  "Date de dernière déconnexion Samba",

# LSobjects.LSpeople.attrs.sambaLogonTime.label
"Samba last logon time" =>
  "Date de dernière connexion Samba",

# LSobjects.LSpeople.attrs.sambaLogonScript.label
"Samba logon script" =>
  "Script de login Samba",

# LSobjects.LSpeople.attrs.sambaHomeDrive.label
"Samba network drive of the home directory" =>
  "Lecteur réseau du dossier personnel Samba",

# LSobjects.LSpeople.attrs.sambaHomePath.label
"Samba network path of the home directory" =>
  "Chemin réseau du dossier personnel Samba",

# LSobjects.LSpeople.attrs.sambaProfilePath.label
"Samba network path of the profile" =>
  "Chemin réseau du profil Samba",

# LSobjects.LSpeople.attrs.sambaPwdCanChange.label
"Samba password can change" =>
  "Date de prochaine modification possible du mot de passe Samba",

# LSobjects.LSpeople.attrs.sambaPwdLastSet.label
"Samba password last change time" =>
  "Date de dernière modification du mot de passe Samba",

# LSobjects.LSpeople.attrs.sambaPwdMustChange.label
"Samba password must change" =>
  "Date de prochaine modification obligatoire du mot de passe Samba",

# LSobjects.LSpeople.attrs.sambaPrimaryGroupSID.label
"Samba primary group identifier" =>
  "Identifiant du groupe primaire Samba",

# LSobjects.LSpeople.customActions.showTechInfo.label
# LSobjects.LSgroup.customActions.showTechInfo.label
# LSobjects.LSsysaccount.customActions.showTechInfo.label
# LSobjects.LScompany.customActions.showTechInfo.label
"Show technical information" =>
  "Afficher les informations techniques",

# LSobjects.LSpeople.LSform.dataEntryForm.simple.label
"Simple" =>
  "Simple",

# LSobjects.LSpeople.attrs.sambaKickoffTime.help_info
"Specifies the time when the user will be locked down and cannot login any longer." =>
  "Détermine la date à partir de laquelle l'utilisateur sera bloqué et ne pourra plus se connecter.",

# LSobjects.LSsysaccount.label
"System accounts" =>
  "Comptes systèmes",

# LSobjects.LSpeople.attrs.givenName.check_data.alphanumeric.msg
"The first name must contain alphanumeric values only." =>
  "Le prénom doit contenir uniquement des caractères alpha-numérique.",

# LSobjects.LSpeople.attrs.shadowInactive.check_data.integer.msg
"The inactivity allowed must be an positive integer." =>
  "La durée d'inactivité autorisée doit être un entier positif.",

# LSobjects.LSpeople.attrs.shadowMax.help_info
"The maximum number of days the password is valid." =>
  "Le nombre de jours maximum durant lequel le mot de passe sera valide.",

# LSobjects.LSpeople.attrs.shadowInactive.help_info
"The number of days of inactivity allowed for the specified user." =>
  "Le nombre de jours d'inactivité autorisée pour cet utilisateur.",

# LSobjects.LSpeople.attrs.uidNumber.check_data.numeric.msg
"The numeric identifier must be an integer." =>
  "L'identifiant numérique doit forcement être un entier.",

# LSobjects.LSpeople.attrs.shadowMax.check_data.integer.msg
"The password validity must be an positive integer." =>
  "La durée de validité du mot de passe doit être un entier positif.",

# LSobjects.LSpeople.attrs.gidNumber.validation.0.msg
"This group doesn't exist." =>
  "Ce groupe n'existe pas.",

# LSobjects.LSpeople.attrs.uid.validation.0.msg
# LSobjects.LSsysaccount.attrs.uid.validation.0.msg
"This identifier is already used." =>
  "Cet identifiant est déjà utilisé.",

# LSobjects.LSsysaccount.attrs.userPassword.check_data.password.msg
"This password must contain at least 12 characters." =>
  "Ce mot de passe doit contenir au moins 12 caractères.",

# LSobjects.LSpeople.attrs.uidNumber.validation.0.msg
"This uid is already used." =>
  "Cet uid est déjà utilisé.",

# ldap_servers.0.recoverPassword.recoveryHashMail.msg
# ldap_servers.1.recoverPassword.recoveryHashMail.msg
"To proceed password recovery procedure, please follow that link:
%{url}" =>
  "Pour poursuivre la procédure de récupération de mot de passe, merci de suivre ce lien :
%{url}",

# LSobjects.LSpeople.label
"Users" =>
  "Utilisateurs",

# LSobjects.LSpeople.attrs.sambaPwdCanChange.html_options.special_values.0
"Whenever" =>
  "N'importe quand",

# LSobjects.LSpeople.LSsearch.predefinedFilters.(jpegPhoto=*)
"With photo" =>
  "Avec photo",

# LSobjects.LSpeople.LSsearch.predefinedFilters.(!(jpegPhoto=*))
"Without photo" =>
  "Sans photo",

# ldap_servers.0.recoverPassword.newPasswordMail.msg
# ldap_servers.1.recoverPassword.newPasswordMail.msg
"Your new password : %{mdp}" =>
  "Votre nouveau mot de passe : %{mdp}",

# LSobjects.LSpeople.attrs.userPassword.html_options.mail.msg
"Your password has been changed.
Login : %{uid}
New password : %{password}" =>
  "Votre mot de passe a été changé.
Identifiant : %{uid}
Nouveau mot de passe : %{password}",

# LSobjects.LSpeople.attrs.userPassword.check_data.password.msg
"Your password must contain from 8 to 10 characters and contains at least one caracter that match with 3 of this types :<ul><li>Uppercase unaccent character</li><li>Lowercase unaccent character</li><li>Digit</li><li>Anything that is not a letter or a digit</li></ul>" =>
  "Votre mot de passe doit contenir entre 8 et 10 caractères et comprendre au moins un caractère correspondant à au moins trois des types suivant :<ul><li>Une lettre majuscule sans accent</li><li>Une lettre minuscule sans accent</li><li>Un chiffre</li><li>Un caractère autre qu'une lettre ou un chiffre</li></ul>",

);
